@@ -36,7 +36,8 @@ def install_package(pkg: str,
                     buildtype: str,
                     jobs: int,
                     reconfigure=False, 
-                    no_deps=False):
+                    no_deps=False,
+                    src_only=False):
     
     """
     Fetch a recipe file from the default path using the given package name, 
@@ -70,7 +71,7 @@ def install_package(pkg: str,
             pprint(f'depends on {dep} -> build found, building..')   
 
             ok = install_package(dep, srcroot, buildroot, installdir, 
-                    buildtype, jobs, reconfigure, no_deps=True)   
+                    buildtype, jobs, reconfigure, no_deps=no_deps, src_only=src_only)   
 
             if not ok:
                 pprint(f'failed to build dependency {dep}')
@@ -93,7 +94,7 @@ def install_package(pkg: str,
             
             # note: reconfigure needed if there's build but not install
             ok = install_package(dep, srcroot, buildroot, installdir, 
-                    buildtype, jobs, reconfigure, no_deps=no_deps)
+                    buildtype, jobs, reconfigure, no_deps=no_deps, src_only=src_only)
 
             if not ok:
                 pprint(f'failed to install dependency {dep}')
@@ -109,13 +110,17 @@ def install_package(pkg: str,
         return False 
     
     # configure and build
-    ok = build_package(pkg=pkg, 
-                       srcroot=srcroot, 
-                       buildroot=buildroot, 
-                       installdir=installdir, 
-                       buildtype=buildtype, 
-                       jobs=jobs, 
-                       reconfigure=reconfigure)
+    if src_only:
+        pprint('src_only mode: will not build')
+        ok = True
+    else:
+        ok = build_package(pkg=pkg, 
+                        srcroot=srcroot, 
+                        buildroot=buildroot, 
+                        installdir=installdir, 
+                        buildtype=buildtype, 
+                        jobs=jobs, 
+                        reconfigure=reconfigure)
 
     if ok:
         pprint('ok')
@@ -137,24 +142,25 @@ def uninstall_package(pkg: str,
         pprint(f'recipe file not found (searched in {Cookbook.get_recipe_basedir()})')
         return False
 
-    builddir = os.path.join(buildroot, pkg.name)
-    manifest_fname = os.path.join(builddir, 'install_manifest.txt')
-    if not os.path.isfile(manifest_fname):
-        pprint(f'missing install_manifest.txt: {manifest_fname}')
+    install_cache_fname = os.path.join(installdir, ".install_cache", pkg.name)
+    if not os.path.isfile(install_cache_fname):
+        pprint(f"missing information: {install_cache_fname}\nare you sure the recipe '{pkg.name}' is installed?")
         return False
 
     error = False
-    with open(manifest_fname, 'r') as manifest:
-        for file in manifest.readlines():
+    with open(install_cache_fname, 'r') as install_cache:
+        for file in install_cache.readlines():
             fname = str(file).rstrip()
             if not _remove_fname(pkg.name, fname, installdir, verbose):
                 error = True
 
     if not error:
+        cmd = ['rm', install_cache_fname]
+        ok = proc_utils.call_process(args=cmd, print_on_error=verbose)
+        
         pprint('uninstalled successfully')
         return True
 
-    pprint('errors occurred during uninstallation')
     return False
 
 
@@ -167,43 +173,32 @@ def _remove_fname(pkg: str, fname: str, installdir:str, verbose: bool):
         return True
 
     if not os.path.islink(fname) and not os.path.exists(fname):
-        pprint(f'removing:  {fname} --> no such file or directory')
+        if verbose:
+            pprint(f'removing:  {fname} --> no such file or directory')
         fname = os.path.split(fname)[0]
         return _remove_fname(pkg, fname, installdir, verbose)
 
     elif not os.path.isdir(fname) or len(os.listdir(fname)) == 0:
-        pprint(f'removing:  {fname}', end="")
+        if verbose:
+            pprint(f'removing:  {fname}', end="")
         cmd = ['rm', '-r', fname]
         ok = proc_utils.call_process(args=cmd, print_on_error=verbose)
         if ok:
-            print(' --> done')
+            if verbose:
+                print(' --> done')
             fname = os.path.split(fname)[0]
             return _remove_fname(pkg, fname, installdir, verbose)
 
         else:
-            print(' --> error removing file or directory')
+            if verbose:
+                print(' --> error removing file or directory')
             return False
 
     return True
 
 
 def clean(pkg: str, buildroot: str,  installdir: str, verbose: bool):
-    pprint = ProgressReporter.get_print_fn(pkg)
-    pprint(f'cleaning..')
-    if not uninstall_package(pkg=pkg, buildroot=buildroot, installdir=installdir, verbose=verbose):
-        pprint('uninstall failed')
-
-        while True:
-            remove_build = input('Do you want to remove build dir anyway? yes or no\n')
-            if remove_build in ('y', 'yes'):
-                return _remove_buildir(pkg, verbose)
-
-            elif remove_build in ('no', 'n'):
-                return True
-
-            else:
-                print('INVALID INPUT: valid options are {yes, y, no, n}\n')
-
+    pprint = ProgressReporter.get_print_fn(pkg)      
     return _remove_buildir(pkg, verbose)
 
 
@@ -225,6 +220,15 @@ def write_setup_file():
     Write a setup file to the root directory.
     """
 
+    # compute relative site-package path 
+    # without using distutils, which is deprecated
+    import sys 
+    import sysconfig
+    import site
+    platlib_path = sysconfig.get_path(name='platlib')    
+    platlib_relpath = os.path.relpath(path=site.USER_SITE, start=site.USER_BASE)
+
+    # replace placeholders
     this_dir = os.path.dirname(os.path.abspath(__file__))
     setup_template = os.path.join(this_dir, 'setup.bash')
     with open(setup_template, 'r') as f:
@@ -232,6 +236,7 @@ def write_setup_file():
         content = content.replace('£PREFIX£', os.path.realpath(installdir))
         content = content.replace('£SRCDIR£', os.path.realpath(srcroot))
         content = content.replace('£ROOTDIR£', os.path.realpath(rootdir))
+        content = content.replace('£REL_SITE_PKG_PATH£', platlib_relpath)
     
     setup_file = os.path.join(installdir, '..', 'setup.bash')
     if not os.path.exists(setup_file):
