@@ -1,12 +1,12 @@
 import subprocess
 import sys
-import getpass
-import re
 import typing
 import progressbar
+import os
 
 from forest.common import print_utils
 from forest.common.parser import update_progress_bar
+from forest.common.forest_dirs import rootdir
 
 call_process_verbose = False
 
@@ -18,8 +18,7 @@ def call_process(args: typing.List[str] = None,
                  print_on_error=True, 
                  shell: bool=False,
                  timeout=None,
-                 update_regrex_pattern=None,
-                 stderr_to_stdout=False
+                 update_regrex_pattern=None
                  ) -> bool:    
     
     # convert args to string
@@ -53,22 +52,28 @@ def call_process(args: typing.List[str] = None,
 
     try:
         #  # universal_newlines=True equivalent to text=True (backward compatibility)
-        #  see https://docs.python.org/3/library/subprocess.html#subprocess.Popen:~:text=Used%20Arguments.-,The%20universal_newlines%20argument%20is%20equivalent%20to%20text%20and%20is%20provided%20for%20backwards%20compatibility.%20By%20default%2C%20file%20objects%20are%20opened%20in%20binary%20mode.,-New%20in%20version
-        stderr = subprocess.STDOUT if stderr_to_stdout else subprocess.PIPE
         pr = subprocess.Popen(args=popen_args,
                                 stdout=subprocess.PIPE,
-                                stderr=stderr, 
+                                stderr=subprocess.STDOUT, 
                                 cwd=cwd, 
                                 shell=shell, 
                                 executable=executable,
                                 universal_newlines=True)
         
+        lines = []
         if update_regrex_pattern is not None:
-            _progress_bar(pr, update_regrex_pattern)
+            lines = _progress_bar(pr, update_regrex_pattern)
             
         if pr.wait(timeout=timeout) != 0:
-            if print_on_error:
-                print(pr.stderr.read(), file=sys.stderr)  
+            if lines:
+                print_utils.log_file.writelines(lines)
+            else:
+                print_utils.log_file.write(pr.stdout.read())
+            
+            if print_on_error and not verbose:
+                print_utils.log_file.seek(0)  # go to the beginning of the file
+                print(print_utils.log_file.read(), file=sys.stderr)
+
             return False
         
         return True
@@ -87,22 +92,18 @@ def _progress_bar(process, regrex_pattern):
     pbar = progressbar.ProgressBar(maxval=100, \
     widgets=[progressbar.Bar('=', '[', ']'), ' ', progressbar.Percentage()])
     pbar.start()
-    
+    lines = []
+
     while True:
         line = process.stdout.readline()
+        lines.append(line)
 
         if not line:
             pbar.finish()
-            break
+            return lines
             
         update_progress_bar(line, pbar=pbar, regrex_pattern=regrex_pattern)
 
-def _no_progress_bar(process):
-    while True:
-            line = process.stdout.readline()
-
-            if not line:
-                break
 
 def get_output(args, cwd='.', input=None, verbose=False, print_on_error=True, shell=False):
 
