@@ -75,11 +75,17 @@ def do_main():
     grow_parser.add_argument('--clone-depth', required=False, type=int, help='set maximum history depth to save bandwidth')
     grow_parser.add_argument('--cmake-args', nargs='+', required=False, help='specify additional cmake args to be appended to each recipe (leading -D must be omitted)')
     grow_parser.add_argument('--no-deps', '-n', required=False, action='store_true', help='skip dependency fetch and build step')
-    grow_parser.add_argument('--uninstall', required=False, action='store_true', help='uninstall recipe')
-    grow_parser.add_argument('--clean', required=False, action='store_true', help='uninstall recipe and remove build')
+    grow_parser.add_argument('--clean', required=False, action='store_true', help='remove pkg build folder before grow')
     grow_parser.add_argument('--pwd', '-p', required=False, help='user password to be used when sudo permission is required (if empty, user is prompted for password); note: to be used with care, as exposing your password might be harmful!')
     grow_parser.add_argument('--verbose', '-v', required=False, action='store_true', help='print additional information')
+    grow_parser.add_argument('--src-only', '-s', required=False, action='store_true', help='only clone sources')
+    grow_parser.add_argument('--tag-override', '-o', required=False, type=str, help='yaml file containing {pkgname: tag} dictionary')
 
+    cut_cmd = 'cut'
+    cut_parser = subparsers.add_parser(cut_cmd, help='remove build and install')
+    cut_parser.add_argument('recipe', nargs='?', metavar='RECIPE', choices=available_recipes, help='name of recipe to cut')
+    cut_parser.add_argument('--verbose', '-v', required=False, action='store_true', help='print additional information')
+    
     recipes_cmd = 'add-recipes'
     recipes_parser = subparsers.add_parser(recipes_cmd, help='add recipes from git remote')
     recipes_parser.add_argument('url', help='url of the remote (e.g. git@github.com:<username>/<reponame>.git or https://github.com/<username>/<reponame>.git)')
@@ -132,7 +138,7 @@ def do_main():
 
     if not args.verbose:
         from forest.common import print_utils
-        print_utils.log_file = open(args.log_file, 'w')
+        print_utils.log_file = open(args.log_file, 'w+')
 
     # sudo handling 
     if args.command == grow_cmd and args.pwd is not None:
@@ -161,11 +167,17 @@ def do_main():
         from forest.common.fetch_handler import GitFetcher
         GitFetcher.proto_override = args.clone_protocol
 
-    # clone proto
+    # clone depth
     if args.command == grow_cmd and args.clone_depth is not None:
         from forest.common.fetch_handler import GitFetcher
         GitFetcher.depth_override = args.clone_depth
 
+    # clone tag override
+    if args.command == grow_cmd and args.tag_override is not None:
+        from forest.common.fetch_handler import GitFetcher
+        import yaml
+        GitFetcher.tag_overrides = yaml.safe_load(open(args.tag_override, 'r'))
+
     # if required, add a recipe repository to the list of remotes
     if args.command == recipes_cmd:
         print('adding recipes...')
@@ -178,7 +190,7 @@ def do_main():
         return True
 
     # uninstall functionality
-    if args.command == grow_cmd and args.uninstall:
+    if args.command == cut_cmd:
         return uninstall_package(pkg=args.recipe,
                                  buildroot=buildroot,
                                  installdir=installdir,
@@ -186,10 +198,10 @@ def do_main():
 
     # clean functionality
     if args.command == grow_cmd and args.clean:
-        return clean(pkg=args.recipe,
-                     buildroot=buildroot,
-                     installdir=installdir,
-                     verbose=args.verbose)
+        clean(pkg=args.recipe,
+              buildroot=buildroot,
+              installdir=installdir,
+              verbose=args.verbose)
 
     # handle modes
     if args.command == grow_cmd and args.mode is not None:
@@ -216,7 +228,8 @@ def do_main():
                                   buildtype=args.default_build_type,
                                   jobs=args.jobs,
                                   reconfigure=args.force_reconfigure,
-                                  no_deps=args.no_deps
+                                  no_deps=args.no_deps,
+                                  src_only=args.src_only
                                   )
 
         return success
